@@ -237,7 +237,7 @@ chngpt.test = function(formula.null, formula.chngpt, family=c("binomial","gaussi
     
     # save rng state before set.seed in order to restore before exiting this function
     save.seed <- try(get(".Random.seed", .GlobalEnv), silent=TRUE) 
-    if (class(save.seed)=="try-error") {set.seed(1); save.seed <- get(".Random.seed", .GlobalEnv) }                        
+    if (inherits(save.seed,"try-error")) {set.seed(1); save.seed <- get(".Random.seed", .GlobalEnv) }                        
     set.seed(1)    
     
     if(p.val.method=="MC") {
